/*******************************************************************************
* File Name: MyKeyPad_KBD_Int.c  
* Version 1.60
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <MyKeyPad_KBD_Int.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START MyKeyPad_KBD_Int_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE	16
#endif
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void MyKeyPad_KBD_Int_Start(void)
{
    /* For all we know the interrupt is active. */
    MyKeyPad_KBD_Int_Disable();

    /* Set the ISR to point to the MyKeyPad_KBD_Int Interrupt. */
    MyKeyPad_KBD_Int_SetVector(MyKeyPad_KBD_Int_Interrupt);

    /* Set the priority. */
    MyKeyPad_KBD_Int_SetPriority(MyKeyPad_KBD_Int_INTC_PRIOR_NUMBER);

    /* Enable it. */
    MyKeyPad_KBD_Int_Enable();
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void MyKeyPad_KBD_Int_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    MyKeyPad_KBD_Int_Disable();

    /* Set the ISR to point to the MyKeyPad_KBD_Int Interrupt. */
    MyKeyPad_KBD_Int_SetVector(address);

    /* Set the priority. */
    MyKeyPad_KBD_Int_SetPriority(MyKeyPad_KBD_Int_INTC_PRIOR_NUMBER);

    /* Enable it. */
    MyKeyPad_KBD_Int_Enable();
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void MyKeyPad_KBD_Int_Stop(void) 
{
    /* Disable this interrupt. */
    MyKeyPad_KBD_Int_Disable();

    /* Set the ISR to point to the passive one. */
    MyKeyPad_KBD_Int_SetVector(IntDefaultHandler);
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for MyKeyPad_KBD_Int.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(MyKeyPad_KBD_Int_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START MyKeyPad_KBD_Int_Interrupt` */

    /* `#END` */
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling MyKeyPad_KBD_Int_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use MyKeyPad_KBD_Int_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void MyKeyPad_KBD_Int_SetVector(cyisraddress address) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + MyKeyPad_KBD_Int__INTC_NUMBER] = address;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress MyKeyPad_KBD_Int_GetVector(void) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + MyKeyPad_KBD_Int__INTC_NUMBER];
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling MyKeyPad_KBD_Int_Start
*   or MyKeyPad_KBD_Int_StartEx will override any effect this method would have had. 
*	This method should only be called after MyKeyPad_KBD_Int_Start or 
*	MyKeyPad_KBD_Int_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void MyKeyPad_KBD_Int_SetPriority(uint8 priority) 
{
    *MyKeyPad_KBD_Int_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 MyKeyPad_KBD_Int_GetPriority(void) 
{
    uint8 priority;


    priority = *MyKeyPad_KBD_Int_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void MyKeyPad_KBD_Int_Enable(void) 
{
    /* Enable the general interrupt. */
    *MyKeyPad_KBD_Int_INTC_SET_EN = MyKeyPad_KBD_Int__INTC_MASK;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 MyKeyPad_KBD_Int_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*MyKeyPad_KBD_Int_INTC_SET_EN & MyKeyPad_KBD_Int__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void MyKeyPad_KBD_Int_Disable(void) 
{
    /* Disable the general interrupt. */
    *MyKeyPad_KBD_Int_INTC_CLR_EN = MyKeyPad_KBD_Int__INTC_MASK;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void MyKeyPad_KBD_Int_SetPending(void) 
{
    *MyKeyPad_KBD_Int_INTC_SET_PD = MyKeyPad_KBD_Int__INTC_MASK;
}

/*******************************************************************************
* Function Name: MyKeyPad_KBD_Int_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void MyKeyPad_KBD_Int_ClearPending(void) 
{
    *MyKeyPad_KBD_Int_INTC_CLR_PD = MyKeyPad_KBD_Int__INTC_MASK;
}
