/*******************************************************************************
* File Name: MyKeyPad_ScanTimer.h
* Version 2.30
*
*  Description:
*     Contains the function prototypes and constants available to the timer
*     user module.
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_Timer_v2_30_MyKeyPad_ScanTimer_H)
#define CY_Timer_v2_30_MyKeyPad_ScanTimer_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */


/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Timer_v2_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults
**************************************/

#define MyKeyPad_ScanTimer_Resolution                 32u
#define MyKeyPad_ScanTimer_UsingFixedFunction         0u
#define MyKeyPad_ScanTimer_UsingHWCaptureCounter      0u
#define MyKeyPad_ScanTimer_SoftwareCaptureMode        0u
#define MyKeyPad_ScanTimer_SoftwareTriggerMode        0u
#define MyKeyPad_ScanTimer_UsingHWEnable              0u
#define MyKeyPad_ScanTimer_EnableTriggerMode          0u
#define MyKeyPad_ScanTimer_InterruptOnCaptureCount    0u
#define MyKeyPad_ScanTimer_RunModeUsed                0u
#define MyKeyPad_ScanTimer_ControlRegRemoved          0u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for Timer Component
 *************************************************************************/
typedef struct MyKeyPad_ScanTimer_backupStruct
{
    uint8 TimerEnableState;
    #if(!MyKeyPad_ScanTimer_UsingFixedFunction)
        #if (CY_PSOC5A)
            uint32 TimerUdb;                 /* Timer internal counter value */
            uint32 TimerPeriod;              /* Timer Period value       */
            uint8 InterruptMaskValue;       /* Timer Compare Value */
            #if (MyKeyPad_ScanTimer_UsingHWCaptureCounter)
                uint32 TimerCaptureCounter;  /* Timer Capture Counter Value */
            #endif /* variable declaration for backing up Capture Counter value*/
        #endif /* variables for non retention registers in PSoC5A */

        #if (CY_PSOC3 || CY_PSOC5LP)
            uint32 TimerUdb;
            uint8 InterruptMaskValue;
            #if (MyKeyPad_ScanTimer_UsingHWCaptureCounter)
                uint32 TimerCaptureCounter;
            #endif /* variable declarations for backing up non retention registers in PSoC3 or PSoC5LP */
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */

        #if (!MyKeyPad_ScanTimer_ControlRegRemoved)
        uint8 TimerControlRegister;
        #endif /* variable declaration for backing up enable state of the Timer */
    #endif /* define backup variables only for UDB implementation. Fixed function registers are all retention */
}MyKeyPad_ScanTimer_backupStruct;


/***************************************
*       Function Prototypes
***************************************/

void    MyKeyPad_ScanTimer_Start(void) ;
void    MyKeyPad_ScanTimer_Stop(void) ;

void    MyKeyPad_ScanTimer_SetInterruptMode(uint8 interruptMode) ;
uint8   MyKeyPad_ScanTimer_ReadStatusRegister(void) ;
/* Deprecated function. Do not use this in future. Retained for backward compatibility */
#define MyKeyPad_ScanTimer_GetInterruptSource() MyKeyPad_ScanTimer_ReadStatusRegister()

#if(!MyKeyPad_ScanTimer_ControlRegRemoved)
    uint8   MyKeyPad_ScanTimer_ReadControlRegister(void) ;
    void    MyKeyPad_ScanTimer_WriteControlRegister(uint8 control) \
        ;
#endif /* (!MyKeyPad_ScanTimer_ControlRegRemoved) */

uint32  MyKeyPad_ScanTimer_ReadPeriod(void) ;
void    MyKeyPad_ScanTimer_WritePeriod(uint32 period) \
    ;
uint32  MyKeyPad_ScanTimer_ReadCounter(void) ;
void    MyKeyPad_ScanTimer_WriteCounter(uint32 counter) \
    ;
uint32  MyKeyPad_ScanTimer_ReadCapture(void) ;
void    MyKeyPad_ScanTimer_SoftwareCapture(void) ;


#if(!MyKeyPad_ScanTimer_UsingFixedFunction) /* UDB Prototypes */
    #if (MyKeyPad_ScanTimer_SoftwareCaptureMode)
        void    MyKeyPad_ScanTimer_SetCaptureMode(uint8 captureMode) ;
    #endif /* (!MyKeyPad_ScanTimer_UsingFixedFunction) */

    #if (MyKeyPad_ScanTimer_SoftwareTriggerMode)
        void    MyKeyPad_ScanTimer_SetTriggerMode(uint8 triggerMode) ;
    #endif /* (MyKeyPad_ScanTimer_SoftwareTriggerMode) */
    #if (MyKeyPad_ScanTimer_EnableTriggerMode)
        void    MyKeyPad_ScanTimer_EnableTrigger(void) ;
        void    MyKeyPad_ScanTimer_DisableTrigger(void) ;
    #endif /* (MyKeyPad_ScanTimer_EnableTriggerMode) */

    #if(MyKeyPad_ScanTimer_InterruptOnCaptureCount)
        #if(!MyKeyPad_ScanTimer_ControlRegRemoved)
            void    MyKeyPad_ScanTimer_SetInterruptCount(uint8 interruptCount) \
                ;
        #endif /* (!MyKeyPad_ScanTimer_ControlRegRemoved) */
    #endif /* (MyKeyPad_ScanTimer_InterruptOnCaptureCount) */

    #if (MyKeyPad_ScanTimer_UsingHWCaptureCounter)
        void    MyKeyPad_ScanTimer_SetCaptureCount(uint8 captureCount) \
            ;
        uint8   MyKeyPad_ScanTimer_ReadCaptureCount(void) ;
    #endif /* (MyKeyPad_ScanTimer_UsingHWCaptureCounter) */

    void MyKeyPad_ScanTimer_ClearFIFO(void) ;
#endif /* UDB Prototypes */

/* Sleep Retention APIs */
void MyKeyPad_ScanTimer_Init(void)          ;
void MyKeyPad_ScanTimer_Enable(void)        ;
void MyKeyPad_ScanTimer_SaveConfig(void)    ;
void MyKeyPad_ScanTimer_RestoreConfig(void) ;
void MyKeyPad_ScanTimer_Sleep(void)         ;
void MyKeyPad_ScanTimer_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Timer__CaptureModes, Used in Capture Mode */
#define MyKeyPad_ScanTimer__B_TIMER__CM_NONE 0
#define MyKeyPad_ScanTimer__B_TIMER__CM_RISINGEDGE 1
#define MyKeyPad_ScanTimer__B_TIMER__CM_FALLINGEDGE 2
#define MyKeyPad_ScanTimer__B_TIMER__CM_EITHEREDGE 3
#define MyKeyPad_ScanTimer__B_TIMER__CM_SOFTWARE 4



/* Enumerated Type B_Timer__TriggerModes, Used in Trigger Mode */
#define MyKeyPad_ScanTimer__B_TIMER__TM_NONE 0x00u
#define MyKeyPad_ScanTimer__B_TIMER__TM_RISINGEDGE 0x04u
#define MyKeyPad_ScanTimer__B_TIMER__TM_FALLINGEDGE 0x08u
#define MyKeyPad_ScanTimer__B_TIMER__TM_EITHEREDGE 0x0Cu
#define MyKeyPad_ScanTimer__B_TIMER__TM_SOFTWARE 0x10u


/***************************************
*    Initialial Parameter Constants
***************************************/

#define MyKeyPad_ScanTimer_INIT_PERIOD             479999u
#define MyKeyPad_ScanTimer_INIT_CAPTURE_MODE       (0u << MyKeyPad_ScanTimer_CTRL_CAP_MODE_SHIFT)
#define MyKeyPad_ScanTimer_INIT_TRIGGER_MODE       (0u << MyKeyPad_ScanTimer_CTRL_TRIG_MODE_SHIFT)
#if (MyKeyPad_ScanTimer_UsingFixedFunction)
    #define MyKeyPad_ScanTimer_INIT_INTERRUPT_MODE ((1u << MyKeyPad_ScanTimer_STATUS_TC_INT_MASK_SHIFT) | \
                                                  (0 << MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK_SHIFT))
#else
    #define MyKeyPad_ScanTimer_INIT_INTERRUPT_MODE ((1u << MyKeyPad_ScanTimer_STATUS_TC_INT_MASK_SHIFT) | \
                                                 (0 << MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK_SHIFT) | \
                                                 (0 << MyKeyPad_ScanTimer_STATUS_FIFOFULL_INT_MASK_SHIFT))
#endif /* (MyKeyPad_ScanTimer_UsingFixedFunction) */
#define MyKeyPad_ScanTimer_INIT_CAPTURE_COUNT      (2u)
#define MyKeyPad_ScanTimer_INIT_INT_CAPTURE_COUNT  ((1u - 1) << MyKeyPad_ScanTimer_CTRL_INTCNT_SHIFT)


/***************************************
*           Registers
***************************************/

#if (MyKeyPad_ScanTimer_UsingFixedFunction) /* Implementation Specific Registers and Register Constants */


    /***************************************
    *    Fixed Function Registers
    ***************************************/

    #define MyKeyPad_ScanTimer_STATUS         (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define MyKeyPad_ScanTimer_STATUS_MASK    (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__SR0 )
    #define MyKeyPad_ScanTimer_CONTROL        (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__CFG0)
    #define MyKeyPad_ScanTimer_CONTROL2       (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__CFG1)
    #define MyKeyPad_ScanTimer_CONTROL2_PTR   ( (reg8 *) MyKeyPad_ScanTimer_TimerHW__CFG1)
    #define MyKeyPad_ScanTimer_RT1            (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__RT1)
    #define MyKeyPad_ScanTimer_RT1_PTR        ( (reg8 *) MyKeyPad_ScanTimer_TimerHW__RT1)

    #if (CY_PSOC3 || CY_PSOC5LP)
        #define MyKeyPad_ScanTimer_CONTROL3       (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__CFG2)
        #define MyKeyPad_ScanTimer_CONTROL3_PTR   ( (reg8 *) MyKeyPad_ScanTimer_TimerHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define MyKeyPad_ScanTimer_GLOBAL_ENABLE  (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__PM_ACT_CFG)
    #define MyKeyPad_ScanTimer_GLOBAL_STBY_ENABLE  (*(reg8 *) MyKeyPad_ScanTimer_TimerHW__PM_STBY_CFG)

    #define MyKeyPad_ScanTimer_CAPTURE_LSB         (* (reg16 *) MyKeyPad_ScanTimer_TimerHW__CAP0 )
    #define MyKeyPad_ScanTimer_CAPTURE_LSB_PTR       ((reg16 *) MyKeyPad_ScanTimer_TimerHW__CAP0 )
    #define MyKeyPad_ScanTimer_PERIOD_LSB          (* (reg16 *) MyKeyPad_ScanTimer_TimerHW__PER0 )
    #define MyKeyPad_ScanTimer_PERIOD_LSB_PTR        ((reg16 *) MyKeyPad_ScanTimer_TimerHW__PER0 )
    #define MyKeyPad_ScanTimer_COUNTER_LSB         (* (reg16 *) MyKeyPad_ScanTimer_TimerHW__CNT_CMP0 )
    #define MyKeyPad_ScanTimer_COUNTER_LSB_PTR       ((reg16 *) MyKeyPad_ScanTimer_TimerHW__CNT_CMP0 )


    /***************************************
    *    Register Constants
    ***************************************/

    /* Fixed Function Block Chosen */
    #define MyKeyPad_ScanTimer_BLOCK_EN_MASK                     MyKeyPad_ScanTimer_TimerHW__PM_ACT_MSK
    #define MyKeyPad_ScanTimer_BLOCK_STBY_EN_MASK                MyKeyPad_ScanTimer_TimerHW__PM_STBY_MSK

    /* Control Register Bit Locations */
    /* Interrupt Count - Not valid for Fixed Function Block */
    #define MyKeyPad_ScanTimer_CTRL_INTCNT_SHIFT                  0x00u
    /* Trigger Polarity - Not valid for Fixed Function Block */
    #define MyKeyPad_ScanTimer_CTRL_TRIG_MODE_SHIFT               0x00u
    /* Trigger Enable - Not valid for Fixed Function Block */
    #define MyKeyPad_ScanTimer_CTRL_TRIG_EN_SHIFT                 0x00u
    /* Capture Polarity - Not valid for Fixed Function Block */
    #define MyKeyPad_ScanTimer_CTRL_CAP_MODE_SHIFT                0x00u
    /* Timer Enable - As defined in Register Map, part of TMRX_CFG0 register */
    #define MyKeyPad_ScanTimer_CTRL_ENABLE_SHIFT                  0x00u

    /* Control Register Bit Masks */
    #define MyKeyPad_ScanTimer_CTRL_ENABLE                        (0x01u << MyKeyPad_ScanTimer_CTRL_ENABLE_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define MyKeyPad_ScanTimer_CTRL2_IRQ_SEL_SHIFT                 0x00u
    #define MyKeyPad_ScanTimer_CTRL2_IRQ_SEL                      (0x01u << MyKeyPad_ScanTimer_CTRL2_IRQ_SEL_SHIFT)

    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        /* As defined by Verilog Implementation */
        #define MyKeyPad_ScanTimer_CTRL_MODE_SHIFT                     0x01u
        #define MyKeyPad_ScanTimer_CTRL_MODE_MASK                     (0x07u << MyKeyPad_ScanTimer_CTRL_MODE_SHIFT)
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Control3 Register Bit Locations */
        #define MyKeyPad_ScanTimer_CTRL_RCOD_SHIFT        0x02u
        #define MyKeyPad_ScanTimer_CTRL_ENBL_SHIFT        0x00u
        #define MyKeyPad_ScanTimer_CTRL_MODE_SHIFT        0x00u

        /* Control3 Register Bit Masks */
        #define MyKeyPad_ScanTimer_CTRL_RCOD_MASK  (0x03u << MyKeyPad_ScanTimer_CTRL_RCOD_SHIFT) /* ROD and COD bit masks */
        #define MyKeyPad_ScanTimer_CTRL_ENBL_MASK  (0x80u << MyKeyPad_ScanTimer_CTRL_ENBL_SHIFT) /* HW_EN bit mask */
        #define MyKeyPad_ScanTimer_CTRL_MODE_MASK  (0x03u << MyKeyPad_ScanTimer_CTRL_MODE_SHIFT) /* Run mode bit mask */

        #define MyKeyPad_ScanTimer_CTRL_RCOD       (0x03u << MyKeyPad_ScanTimer_CTRL_RCOD_SHIFT)
        #define MyKeyPad_ScanTimer_CTRL_ENBL       (0x80u << MyKeyPad_ScanTimer_CTRL_ENBL_SHIFT)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define MyKeyPad_ScanTimer_RT1_SHIFT                       0x04u
    /* Sync TC and CMP bit masks */
    #define MyKeyPad_ScanTimer_RT1_MASK                        (0x03u << MyKeyPad_ScanTimer_RT1_SHIFT)
    #define MyKeyPad_ScanTimer_SYNC                            (0x03u << MyKeyPad_ScanTimer_RT1_SHIFT)
    #define MyKeyPad_ScanTimer_SYNCDSI_SHIFT                   0x00u
    /* Sync all DSI inputs with Mask  */
    #define MyKeyPad_ScanTimer_SYNCDSI_MASK                    (0x0Fu << MyKeyPad_ScanTimer_SYNCDSI_SHIFT)
    /* Sync all DSI inputs */
    #define MyKeyPad_ScanTimer_SYNCDSI_EN                      (0x0Fu << MyKeyPad_ScanTimer_SYNCDSI_SHIFT)

    #define MyKeyPad_ScanTimer_CTRL_MODE_PULSEWIDTH            (0x01u << MyKeyPad_ScanTimer_CTRL_MODE_SHIFT)
    #define MyKeyPad_ScanTimer_CTRL_MODE_PERIOD                (0x02u << MyKeyPad_ScanTimer_CTRL_MODE_SHIFT)
    #define MyKeyPad_ScanTimer_CTRL_MODE_CONTINUOUS            (0x00u << MyKeyPad_ScanTimer_CTRL_MODE_SHIFT)

    /* Status Register Bit Locations */
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define MyKeyPad_ScanTimer_STATUS_TC_SHIFT                 0x07u
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT            0x06u
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define MyKeyPad_ScanTimer_STATUS_TC_INT_MASK_SHIFT        (MyKeyPad_ScanTimer_STATUS_TC_SHIFT - 4)
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK_SHIFT   (MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT - 4)

    /* Status Register Bit Masks */
    #define MyKeyPad_ScanTimer_STATUS_TC                       (0x01u << MyKeyPad_ScanTimer_STATUS_TC_SHIFT)
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE                  (0x01u << MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT)
    /* Interrupt Enable Bit-Mask for interrupt on TC */
    #define MyKeyPad_ScanTimer_STATUS_TC_INT_MASK              (0x01u << MyKeyPad_ScanTimer_STATUS_TC_INT_MASK_SHIFT)
    /* Interrupt Enable Bit-Mask for interrupt on Capture */
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK         (0x01u << MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK_SHIFT)

#else   /* UDB Registers and Register Constants */


    /***************************************
    *           UDB Registers
    ***************************************/

    #define MyKeyPad_ScanTimer_STATUS              (* (reg8 *) MyKeyPad_ScanTimer_TimerUDB_nrstSts_stsreg__STATUS_REG )
    #define MyKeyPad_ScanTimer_STATUS_MASK         (* (reg8 *) MyKeyPad_ScanTimer_TimerUDB_nrstSts_stsreg__MASK_REG)
    #define MyKeyPad_ScanTimer_STATUS_AUX_CTRL     (* (reg8 *) MyKeyPad_ScanTimer_TimerUDB_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define MyKeyPad_ScanTimer_CONTROL             (* (reg8 *) MyKeyPad_ScanTimer_TimerUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )

    #define MyKeyPad_ScanTimer_CAPTURE_LSB         (* (reg32 *) MyKeyPad_ScanTimer_TimerUDB_sT32_timerdp_u0__F0_REG )
    #define MyKeyPad_ScanTimer_CAPTURE_LSB_PTR       ((reg32 *) MyKeyPad_ScanTimer_TimerUDB_sT32_timerdp_u0__F0_REG )
    #define MyKeyPad_ScanTimer_PERIOD_LSB          (* (reg32 *) MyKeyPad_ScanTimer_TimerUDB_sT32_timerdp_u0__D0_REG )
    #define MyKeyPad_ScanTimer_PERIOD_LSB_PTR        ((reg32 *) MyKeyPad_ScanTimer_TimerUDB_sT32_timerdp_u0__D0_REG )
    #define MyKeyPad_ScanTimer_COUNTER_LSB         (* (reg32 *) MyKeyPad_ScanTimer_TimerUDB_sT32_timerdp_u0__A0_REG )
    #define MyKeyPad_ScanTimer_COUNTER_LSB_PTR       ((reg32 *) MyKeyPad_ScanTimer_TimerUDB_sT32_timerdp_u0__A0_REG )

    #if (MyKeyPad_ScanTimer_UsingHWCaptureCounter)
        #define MyKeyPad_ScanTimer_CAP_COUNT              (*(reg8 *) MyKeyPad_ScanTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define MyKeyPad_ScanTimer_CAP_COUNT_PTR          ( (reg8 *) MyKeyPad_ScanTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define MyKeyPad_ScanTimer_CAPTURE_COUNT_CTRL     (*(reg8 *) MyKeyPad_ScanTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
        #define MyKeyPad_ScanTimer_CAPTURE_COUNT_CTRL_PTR ( (reg8 *) MyKeyPad_ScanTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
    #endif /* (MyKeyPad_ScanTimer_UsingHWCaptureCounter) */


    /***************************************
    *       Register Constants
    ***************************************/

    /* Control Register Bit Locations */
    #define MyKeyPad_ScanTimer_CTRL_INTCNT_SHIFT              0x00u       /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_CTRL_TRIG_MODE_SHIFT           0x02u       /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_CTRL_TRIG_EN_SHIFT             0x04u       /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_CTRL_CAP_MODE_SHIFT            0x05u       /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_CTRL_ENABLE_SHIFT              0x07u       /* As defined by Verilog Implementation */

    /* Control Register Bit Masks */
    #define MyKeyPad_ScanTimer_CTRL_INTCNT_MASK               (0x03u << MyKeyPad_ScanTimer_CTRL_INTCNT_SHIFT)
    #define MyKeyPad_ScanTimer_CTRL_TRIG_MODE_MASK            (0x03u << MyKeyPad_ScanTimer_CTRL_TRIG_MODE_SHIFT)
    #define MyKeyPad_ScanTimer_CTRL_TRIG_EN                   (0x01u << MyKeyPad_ScanTimer_CTRL_TRIG_EN_SHIFT)
    #define MyKeyPad_ScanTimer_CTRL_CAP_MODE_MASK             (0x03u << MyKeyPad_ScanTimer_CTRL_CAP_MODE_SHIFT)
    #define MyKeyPad_ScanTimer_CTRL_ENABLE                    (0x01u << MyKeyPad_ScanTimer_CTRL_ENABLE_SHIFT)

    /* Bit Counter (7-bit) Control Register Bit Definitions */
    /* As defined by the Register map for the AUX Control Register */
    #define MyKeyPad_ScanTimer_CNTR_ENABLE                    0x20u

    /* Status Register Bit Locations */
    #define MyKeyPad_ScanTimer_STATUS_TC_SHIFT                0x00u  /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT           0x01u  /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_STATUS_TC_INT_MASK_SHIFT       MyKeyPad_ScanTimer_STATUS_TC_SHIFT
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK_SHIFT  MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT
    #define MyKeyPad_ScanTimer_STATUS_FIFOFULL_SHIFT          0x02u  /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_STATUS_FIFONEMP_SHIFT          0x03u  /* As defined by Verilog Implementation */
    #define MyKeyPad_ScanTimer_STATUS_FIFOFULL_INT_MASK_SHIFT MyKeyPad_ScanTimer_STATUS_FIFOFULL_SHIFT

    /* Status Register Bit Masks */
    /* Sticky TC Event Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_TC                      (0x01u << MyKeyPad_ScanTimer_STATUS_TC_SHIFT)
    /* Sticky Capture Event Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE                 (0x01u << MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT)
    /* Interrupt Enable Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_TC_INT_MASK             (0x01u << MyKeyPad_ScanTimer_STATUS_TC_SHIFT)
    /* Interrupt Enable Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_CAPTURE_INT_MASK        (0x01u << MyKeyPad_ScanTimer_STATUS_CAPTURE_SHIFT)
    /* NOT-Sticky FIFO Full Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_FIFOFULL                (0x01u << MyKeyPad_ScanTimer_STATUS_FIFOFULL_SHIFT)
    /* NOT-Sticky FIFO Not Empty Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_FIFONEMP                (0x01u << MyKeyPad_ScanTimer_STATUS_FIFONEMP_SHIFT)
    /* Interrupt Enable Bit-Mask */
    #define MyKeyPad_ScanTimer_STATUS_FIFOFULL_INT_MASK       (0x01u << MyKeyPad_ScanTimer_STATUS_FIFOFULL_SHIFT)

    #define MyKeyPad_ScanTimer_STATUS_ACTL_INT_EN             0x10u   /* As defined for the ACTL Register */

    /* Datapath Auxillary Control Register definitions */
    #define MyKeyPad_ScanTimer_AUX_CTRL_FIFO0_CLR             0x01u   /* As defined by Register map */
    #define MyKeyPad_ScanTimer_AUX_CTRL_FIFO1_CLR             0x02u   /* As defined by Register map */
    #define MyKeyPad_ScanTimer_AUX_CTRL_FIFO0_LVL             0x04u   /* As defined by Register map */
    #define MyKeyPad_ScanTimer_AUX_CTRL_FIFO1_LVL             0x08u   /* As defined by Register map */
    #define MyKeyPad_ScanTimer_STATUS_ACTL_INT_EN_MASK        0x10u   /* As defined for the ACTL Register */

#endif /* Implementation Specific Registers and Register Constants */

#endif  /* CY_Timer_v2_30_MyKeyPad_ScanTimer_H */


/* [] END OF FILE */
