//****************************************************************
//
//	`$INSTANCE_NAME` Matrix KeyPad Component
//	Version 1.0 	August 2012
//	Author:			Bob Marlowe
//	J. Meier Software - Entwicklung
//	Steinfelder Str. 11
//	D-27404 Bruemmerhof
//	(C) 2012 J.Meier Software - Entwicklung
//
//	Given as an Example to the Cypress PSoC community
//	Use as-it-is, use at own risk
//*****************************************************************
/********************************************************************************/
/*																				*/
/*	De-Bouncing of a Keypad, Buffering, Key-Repeating							*/
/*																				*/
/*	Principle of operation:														*/
/*	In an interrupt-routine triggered by a timer the ros and columns			*/
/*	are red to see a keypress.													*/
/*	When a given (adjustable) number of keypresses are seen it is recorded 		*/
/*	in a circular buffer. To increase the flexibility of the component a		*/
/*	translation with a user-supplied lookup-tabe can be done before the 		*/
/*	keypress is recorded.														*/
/*																				*/
/*	For longer keypresses a key-repetition mechanism is implemented with		*/
/*	an adjustable timing.														*/
/*																				*/
/********************************************************************************/
//

//************************ Libraries ********************************************/
#include <device.h>


//************************ Definitions / Macros**********************************/
// Component Parameters
#define TIMER_INTERVAL `$KeyScans`										// Timer period in ms
#define MAX_CHECKS `$NumberOfReadings` 									// Number of Samples Before Key is De-bounced
#define REPEAT_RATE (`$RepDelay`/TIMER_INTERVAL)						// Key Repeat Rate
#define INITIAL_DELAY (`$InitRepDelay`/TIMER_INTERVAL - REPEAT_RATE) 	// 600 ms Wait-Time Before Key first Repeated
/********** Key Buffer **********************/
#define `$INSTANCE_NAME`_KEYBUFFSIZE `$KeyBuffSize`						// Number of Keypresses to buffer
/********************************************/
//*** Definition of the Keyboard Matrix *****/
#define KEYROWS `$RowsNumber`
#define KEYCOLS	`$ColsNumber`
//********** End of Matrix Definition *********************//
#define MAXKEYVALUE (KEYCOLS * KEYROWS)
#define KEYROWMASK ((1 << KEYROWS)-1)									// Mask-bits Row
#define KEYCOLMASK ((1 << KEYCOLS)-1)									// Mask-bits Column
#if KEYCOLS > 4 														// This looks a bit complicated: Here ColShift is set
	#define ColShift 3													// to the number of bits needed to express the column
#else																	
	#if KEYCOLS > 2
		#define ColShift 2
	#else
		#if KEYCOLS > 1
			#define ColShift 1
		#endif
	#endif
#endif
